;; Generated package description from modus-themes.el  -*- no-byte-compile: t -*-
(define-package "modus-themes" "4.3.0" "Elegant, highly legible and customizable themes" '((emacs "27.1")) :commit "fe08a02c4c0501a984b15af3f8c3c5e4769b93ad" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Modus-Themes Development" . "~protesilaos/modus-themes@lists.sr.ht") :keywords '("faces" "theme" "accessibility") :url "https://git.sr.ht/~protesilaos/modus-themes")
